@@ -1,7 +1,7 @@
 
 ;;;### (autoloads nil "_pkg" "auctex/_pkg.el")
 
-(package-provide 'auctex :version 2008.021 :author-version "11.85" :type 'regular)
+(package-provide 'auctex :version 2010.0221 :author-version "11.86" :type 'regular)
 
 ;;;***
 
@@ -96,7 +96,7 @@ of `LaTeX-mode-hook'." t nil)
 
 ;;;***
 
-;;;### (autoloads (multi-prompt) "multi-prompt" "auctex/multi-prompt.el")
+;;;### (autoloads (multi-prompt-key-value multi-prompt) "multi-prompt" "auctex/multi-prompt.el")
 
 (autoload 'multi-prompt "multi-prompt" "\
 Completing prompt for a list of strings.  
@@ -105,6 +105,19 @@ separate the elements in the list.  The second argument UNIQUE should
 be non-nil, if each element must be unique.  The remaining elements
 are the arguments to `completing-read'.  See that." nil nil)
 
+(autoload 'multi-prompt-key-value "multi-prompt" "\
+Read multiple strings, with completion and key=value support.
+PROMPT is a string to prompt with, usually ending with a colon
+and a space.  TABLE is an alist.  The car of each element should
+be a string representing a key and the optional cdr should be a
+list with strings to be used as values for the key.
+
+See the documentation for `completing-read' for details on the
+other arguments: PREDICATE, REQUIRE-MATCH, INITIAL-INPUT, HIST,
+DEF, and INHERIT-INPUT-METHOD.
+
+The return value is the string as entered in the minibuffer." nil nil)
+
 ;;;***
 
 ;;;### (autoloads (preview-report-bug LaTeX-preview-setup preview-install-styles) "preview" "auctex/preview.el")
@@ -298,6 +311,17 @@ Limit searched to BOUND." nil nil)
 (if (< emacs-major-version 21)
   (error "AUCTeX requires Emacs 21 or later"))
 
+;; Define here in order for `M-x customize-group <RET> AUCTeX <RET>'
+;; to work if the main AUCTeX files are not loaded yet.
+(defgroup AUCTeX nil
+  "A (La)TeX environment."
+  :tag "AUCTeX"
+  :link '(custom-manual "(auctex)Top")
+  :link '(url-link :tag "Home Page" "http://www.gnu.org/software/auctex/")
+  :prefix "TeX-"
+  :group 'tex
+  :load "tex" :load "latex" :load "tex-style")
+
 (defvar TeX-lisp-directory
   (file-name-directory load-file-name)
   "The directory where most of the AUCTeX lisp files are located.
@@ -388,13 +412,16 @@ set it with `TeX-modes-set'."
 		      `(TeX-modes-set ',var ,var t))
 		    (setq list (cdr list))))))
 
-(defconst AUCTeX-version "11.85"
+(defconst AUCTeX-version "11.86"
     "AUCTeX version.
 If not a regular release, the date of the last change.")
 
-(defconst AUCTeX-date "2008-02-10"
+(defconst AUCTeX-date "2010-02-21"
   "AUCTeX release date using the ISO 8601 format, yyyy-mm-dd.")
 
+;; Store bibitems when saving a BibTeX buffer
+(add-hook 'bibtex-mode-hook 'BibTeX-auto-store)
+
 (provide 'tex-site)
 
 (add-to-list 'load-path (file-name-directory load-file-name))
