@@ -6,7 +6,7 @@
 
 (custom-add-loads 'TeX-fold '("latex" "tex-fold"))
 (custom-add-loads 'AUCTeX-jp '("tex-jp"))
-(custom-add-loads 'tex '("bib-cite" "font-latex" "tex" "texmathp"))
+(custom-add-loads 'tex '("bib-cite" "font-latex" "texmathp"))
 (custom-add-loads 'ConTeXt-nl-environment '("context-nl"))
 (custom-add-loads 'TeX-tool-bar-button-definitions '("tex-bar"))
 (custom-add-loads 'LaTeX-label '("latex" "tex-style"))
@@ -18,7 +18,6 @@
 (custom-add-loads 'TeX-output '("tex-buf" "tex"))
 (custom-add-loads 'LaTeX-math '("latex"))
 (custom-add-loads 'AUCTeX '("font-latex" "preview" "tex-bar" "tex-fold" "tex-jp" "tex"))
-(custom-add-loads 'TeX-source-specials '("tex"))
 (custom-add-loads 'preview-latex '("preview" "prv-xemacs"))
 (custom-add-loads 'TeX-parse '("tex"))
 (custom-add-loads 'TeX-command '("context" "latex" "tex-buf" "tex-info" "tex"))
@@ -41,6 +40,7 @@
 (custom-add-loads 'preview-gs '("preview"))
 (custom-add-loads 'ConTeXt-macro '("context"))
 (custom-add-loads 'TeX-file-extension '("tex"))
+(custom-add-loads 'TeX-view '("tex"))
 (custom-add-loads 'ConTeXt-environment '("context"))
 (custom-add-loads 'TeX-file '("tex"))
 
